==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebColumnTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebColumnTemplateContextDescription } from "./WebColumnTemplateContextDescription";
/**
 * @hidden
 */
export let WebColumnTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnTemplateContextDescriptionMetadata.a == null) {
                WebColumnTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnTemplateContextDescriptionMetadata.c(WebColumnTemplateContextDescriptionMetadata.a);
            }
            if (a.j(WebColumnTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnTemplateContextDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Implicit", "ExportedType:WebColumn");
            a.item("Column", "ExportedType:WebColumn");
        }
        static d(a) {
            WebColumnTemplateContextDescriptionMetadata.b(a);
            a.aa("WebColumnTemplateContext", () => new WebColumnTemplateContextDescription());
            a.z("WebColumnTemplateContext", WebColumnTemplateContextDescriptionMetadata.a);
        }
    }
    WebColumnTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnTemplateContextDescriptionMetadata, 'WebColumnTemplateContextDescriptionMetadata');
    WebColumnTemplateContextDescriptionMetadata.a = null;
    return WebColumnTemplateContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebColumnTemplateContextDescription } from "./WebColumnTemplateContextDescription";
/**
 * @hidden
 */
export let WebColumnTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnTemplateContextDescriptionMetadata.a == null) {
                WebColumnTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnTemplateContextDescriptionMetadata.c(WebColumnTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebColumnTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnTemplateContextDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ColumnTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebColumn");
            a.item("Column", "ExportedType:WebColumn");
        }
        static d(a) {
            WebColumnTemplateContextDescriptionMetadata.b(a);
            a.ac("WebColumnTemplateContext", () => new WebColumnTemplateContextDescription());
            a.ab("WebColumnTemplateContext", WebColumnTemplateContextDescriptionMetadata.a);
        }
    }
    WebColumnTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnTemplateContextDescriptionMetadata, 'WebColumnTemplateContextDescriptionMetadata');
    WebColumnTemplateContextDescriptionMetadata.a = null;
    return WebColumnTemplateContextDescriptionMetadata;
})();
